<html>
<head>
<script language="VB" runat="server">
Sub ServerValidate(s As Object, e As ServerValidateEventArgs) 
    e.IsValid = ValidateCardVB(e.Value)
End Sub
Function ValidateCardVB(cc) 
    ' Validates credit card number using
    ' check digit algorithm.
    ' Also checks length of number for Visa,
    ' MasterCard, and AmEx cards.
    ' Inputs:  cc -- credit card to be validated.
    ' Outputs: returnvalue -- true if valid, false if invalid
    Dim intCheckSum, intLen, intProduct, intJ As Integer
    Dim strCh As String
    Dim fOK As Boolean
     
    ' Remove Extra Digits (spaces and dashes)
    intLen = Len(cc)
    For intJ = 1 To intLen
        strCh = Mid(cc, intJ, 1)
        If (strCh = " " Or strCh = "-") Then
            If intJ>1 Then
                cc = Left(cc,intJ-1) + Mid(cc,intJ+1)
            Else
                cc = Mid(cc,intJ+1)
            End If
        End If
    Next
    intLen = Len(cc)
    strCh = Left(cc,1)
    If (strCh<>"3" And strCh<>"4" And strCh<>"5") Then
        'Must begin with 3, 4, or 5.
        fOK = False    
    ElseIf (strCh="5" And intLen<>16) Then
        'Mastercard must be 16 digits.
        fOK = False
    ElseIf (strCh="4" And intLen<>13 And intLen<>16) Then
        'Visa numbers must be 13 or 16 digits.
        fOK = False
    ElseIf (strCh="3" And intLen<>15) Then
        'American Express numbers must be 15 digits.
        fOK = False
    Else 
        ' Perform Checksum - Weighting list 2121212121212121....
        intCheckSum = 0
        For intJ = 1 To intLen ' go through entire cc num string
            ' convert char to int
            intProduct = CInt(Mid(cc,intJ,1)) 
            ' if odd digit from end, intProduct=intProduct*2
            If ((intLen-intJ) Mod 2 <> 0) Then 
                intProduct=intProduct*2 
            End If
            ' subtract 9 if intProduct is >=10
            If (intProduct >= 10) Then
                intProduct= intProduct - 9 
            End If
            
            ' add to check
            intCheckSum= intCheckSum + intProduct 
        Next

        ' card good if check divisible by 10 
        If (intCheckSum Mod 10 = 0) Then 
            'No error
            fOK = True
        Else 
            'Invalid check sum
            fOK = False
        End If
    End If

    Return fOK
End Function

</script>

<script language="javascript">
function ClientValidate(s, e) {
    e.IsValid = ValidateCardJS(e.Value)
    }
function ValidateCardJS(cc) {
    /* Validates credit card number using
     check digit algorithm.
     Also checks length of number for Visa,
     MasterCard, and AmEx cards.
     Inputs:  cc -- credit card to be validated.
     Outputs: returnvalue -- true if valid, false if invalid */
    var intCheckSum
    var intLen
    var intProduct
    var intJ
    var strCh
    var fOK
     
    // Remove Extra Digits (spaces and dashes)
    intLen = cc.length
    for(intJ=0; intJ<intLen; intJ++) {
        strCh = cc.charAt(intJ)
        if (strCh == " " || strCh == "-") {
            if(intJ>0) 
                cc = cc.substring(0,intJ) + cc.substring(intJ+1, cc.length)
            else
                cc = cc.substring(intJ+1, cc.length)
        }
       }
    // Recomputed length after stripping spaces & dashes
    intLen = cc.length

    // Check first character
    strCh = cc.charAt(0)
    if (strCh!="3" && strCh!="4" && strCh!="5") {
        //Must begin with 3, 4, or 5
        fOK = false    
        }
    else if (strCh=="5" && intLen!=16) {
        //Mastercard must be 16 digits.
        fOK = false
        }
    else if (strCh=="4" && intLen!=13 && intLen!=16) {
        //Visa numbers must be 13 or 16 digits.
        fOK = false
        }
    else if (strCh=="3" && intLen!=15) {
        //American Express numbers must be 15 digits.
        fOK = false
        }
    else {
        // Perform Checksum - Weighting list 2121212121212121....
        intCheckSum = 0

        // go through entire cc num string
        for (intJ=0;intJ<intLen;intJ++) {
            // convert char to int
            intProduct = parseInt(cc.charAt(intJ))
            // if odd digit from end, intProduct=intProduct*2
            if ((intLen-intJ-1) % 2 != 0) 
                intProduct *= 2 
            // subtract 9 if intProduct is >=10
            if (intProduct >= 10) 
                intProduct -= 9 

            // add to check
            intCheckSum += intProduct 
       }
        // card good if check divisible by 10 
        if (intCheckSum % 10 == 0) {
            // No error 
            fOK = true 
            }
        else {
           // Invalid check sum
            fOK = false
           }
      }
    return fOK
    }

</script>

</head>
<body>

<form runat="server">
  <table>
  <tr>
  <td>Name (as it appears on card):</td>
  <td><asp:TextBox id="txtCardName" 
        columns=30 runat="server" /></td>
  </tr>
  
  <tr>
  <td>Credit Card Number:</td>
  <td><asp:TextBox id="txtCreditCard" 
        columns=30 runat="server" /></td>
  </tr>

  <tr>
  <td>Expiration Date (Month/Year):</td>
  <td><asp:TextBox id="txtCardMo"
       columns=4 runat="server" /> /
      <asp:TextBox id="txtCardYr" 
       columns=4 runat="server" /> </td>
  </tr>
 
  <tr>
  <td><asp:Button type="submit" text="Submit" runat="server" /></td>
  </tr>
  </table>
  <asp:CustomValidator id="cvCreditCard" runat="server"
     ControlToValidate="txtCreditCard"
     OnServerValidate="ServerValidate"
     ClientValidationFunction="ClientValidate"
     Display="Static"
     ErrorMessage="Invalid credit card number."
     EnableClientScript=True
     Font-Name="verdana" Font-Size="14pt">
  </asp:CustomValidator>
</form>
</body>
</html>
