<%@ Page Language="VB" Debug="true" %>
<%@ Import Namespace="System.Data" %>
<%@ Import Namespace="System.XML" %>

<html>
<head>
<title>DataSetToXml.aspx</title>
<script language="VB" runat="server">

Sub Page_Load(Src As Object, E As EventArgs) 
  ' Don't need to rebind for postbacks
  If Not Page.IsPostBack Then
     Call BindDataSet()
  End If
End Sub

Sub BindDataSet()
  ' Create the DataSet and bind to it
  dgrPeople.DataSource = FabricateDataSet()
  dgrPeople.DataBind()
End Sub

Function FabricateDataSet() As DataView
  ' Create new empty DataSet
  Dim dsFab As DataSet = New DataSet
  dsFab.DataSetName = "PeopleSet"
  Dim dtPeople As DataTable = New DataTable
  Dim dc As DataColumn
  Dim drPeople As DataRow

  ' Create the PersonId Column
  dc = New DataColumn
  With dc
    .DataType = System.Type.GetType("System.Int32")
    .ColumnName = "PersonId"
    .Unique = True
    .AutoIncrement = True
    .AutoIncrementSeed = 101
    .AutoIncrementStep = 1
  End With
  dtPeople.Columns.Add(dc)

  ' Create the LastName column
  dc = New DataColumn
  With dc
    .DataType = System.Type.GetType("System.String")
    .ColumnName = "LastName"
  End With
  dtPeople.Columns.Add(dc)
 
  ' Create the FirstName column
  dc = New DataColumn
  With dc
    .DataType = System.Type.GetType("System.String")
    .ColumnName = "FirstName"
  End With
  dtPeople.Columns.Add(dc)

  ' Create the EMail column
  dc = New DataColumn
  With dc
    .DataType = System.Type.GetType("System.String")
    .ColumnName = "Email"
  End With
  dtPeople.Columns.Add(dc)

  ' Make PersonId the primary key of the DataTable
  Dim dcPk() As DataColumn = {dtPeople.Columns("PersonId")}
  dtPeople.PrimaryKey = dcPk

  ' Add the dtPeople DataTable to the dsFab Dataset
  dsFab.Tables.Add(dtPeople)
  dsFab.Tables(0).TableName = "People"

  ' Add a row to dtPeople
  drPeople = dtPeople.NewRow()
  drPeople("LastName") = "Litwin"
  drPeople("FirstName") = "Geoff"
  drPeople("Email") = "geoff@theend.com"
  dtPeople.Rows.Add(drPeople)

  ' Add another row to dtPeople
  drPeople = dtPeople.NewRow()
  drPeople("LastName") = "Elizabeth"
  drPeople("FirstName") = "Anna"
  drPeople("Email") = "anna@toddler.com"
  dtPeople.Rows.Add(drPeople)

  ' And a third row, this time using an array of values
  ' for the fields. Notice that you need to 
  ' pass the AutoIncrement field a value of Nothing
  Dim avalues() As Object = {Nothing, "Lea", "Suzanne", "sl@seattle.net"}
  dtPeople.Rows.Add(aValues)

  ' Cache the DataSet so we can use it when
  ' the button is clicked
  Cache("dsFab") = dsFab

  Return dsFab.Tables("People").DefaultView
End Function

Sub OutputXML(ByRef ds As DataSet, strFile As String)
  Dim fs As New System.IO.FileStream _
   (strFile, System.IO.FileMode.Create)
  ' Create an XmlTextWriter with the fileStream.
  Dim xtw As New System.Xml.XmlTextWriter _
   (fs, System.Text.Encoding.Unicode)

  ' Write to the file with the WriteXml method.
  ds.WriteXml(xtw, XmlWriteMode.WriteSchema)
  xtw.Close()
End Sub

Sub GenerateXML(Src As Object, E As EventArgs)
  Call OutputXML(Cache("dsFab"), Server.MapPath("people.xml"))
  lblMsg.Text = "XML written to " & Server.MapPath("people.xml")
End Sub
</script>
</head>
<body>
<form runat="server">
  <asp:Label id="lblOut" runat="server"
   Text="<h2>Fabricated DataSet Example</h2>" />

  <asp:DataGrid id="dgrPeople" runat="server"
    BorderColor="black"
    BorderWidth="1"
    GridLines="Both"
    CellPadding="3"
    CellSpacing="0"
    Font-Name="Verdana"
    Font-Size="8pt"
    HeaderStyle-BackColor="#99ccff"
    AlternatingItemStyle-BackColor="lightgray" />
  <p><asp:Button id="cmdWrite" runat="server"
      Text="GenerateXML" OnClick="GenerateXML" /></p>
  <asp:Label id="lblMsg" runat="server" 
   style="Color:red" />
</form>
</body>
</html>


