<%@ Page Debug=True %>
<%@ Import Namespace="System.Data" %>
<%@ Import Namespace="System.Data.SqlClient" %>

<html>
<head>
<title>SqlDataSetUpdate.aspx</title>
<script language="VB" runat="server">
' ds variable is global to page
Dim ds as DataSet

Sub Page_Load(Src As Object, E As EventArgs) 
  Call GetDataSet()
  ' Only need to bind the first time through
  ' Otherwise, binding will occur after the
  ' Edit/Update/Cancel events.
  If Not Page.IsPostBack Then
     Call BindDataSet()
  End If
  
  ' Enable Commit/Abandon buttons if DataSet
  ' has pending changes.
  Call EnableDbButtons(ds.HasChanges())
End Sub

Sub BindDataSet()
  ' Bind ds DataSet to DataGrid

  dgrEmployees.DataSource = ds
  dgrEmployees.DataBind()
End Sub

Sub GetDataSet()
  ' Check if dataset has already been built and 
  ' stored in Session. If not, then build it.

  If Session("ds") Is Nothing Then
    ' Build DataSet from database
    Call BuildDataSet()
  Else
    ' Retrieve DataSet from session variable
    ds = Session("ds") 
  End If
End Sub

Sub BuildDataSet()
  ' This routine builds the DataSet from 
  ' the Northwind Employees table.

  Dim strCnx As String = "server=localhost;uid=sa;pwd=;database=northwind;"
  Dim strSQL As String = "SELECT * FROM Employees"

  ' Create connection to SQL Server Northwind database
  Dim cnx As SqlConnection = New SqlConnection(strCnx)
  ' Create & execute SqlDataAdapter query to return records
  Dim sda As SqlDataAdapter = New SqlDataAdapter(strSQL, cnx)

  ' Make sure we can update rows by forcing the inclusion
  ' of the primary key columns. Not really necessary in this example.
  sda.MissingSchemaAction = MissingSchemaAction.AddWithKey

  ' Create new empty DataSet
  ds = New DataSet
	
  ' Fill DataSet using SqlDataAdapter
  sda.Fill(ds,"Employees")

  ' Set the PrimaryKey for Employees DataTable
  Dim dcPk() As DataColumn = {ds.Tables("Employees").Columns("EmployeeId")}
  ds.Tables("Employees").PrimaryKey = dcPk
    
  ' Store DataSet to session variable
  Session("ds") = ds

  cnx.Close()
End Sub

Sub EnableDbButtons(blnEnable)
  ' Helper routine to enable/disable
  ' Database Update buttons.

  cmdDbCommit.Enabled = blnEnable
  cmdDbAbandon.Enabled = blnEnable

  ' If enabled then DataSet must be dirty.
  If blnEnable Then
    lblMsg.Text = "Pending changes."
  End If
End Sub

Sub GridEdit(sender As Object, e As DataGridCommandEventArgs)
  ' This code is executed when the Edit button 
  ' associated with the EditCommandColumn is clicked.

  ' Set the EditItemIndex to the index of the row 
  ' that triggered the Edit event
  dgrEmployees.EditItemIndex = e.Item.ItemIndex
  Call BindDataSet()

  ' Disable buttons and clear message during editing
  Call EnableDbButtons(False)
  lblMsg.Text = ""
End Sub

Sub GridCancel(sender As Object, e As DataGridCommandEventArgs)
  ' This code is executed when the Cancel button 
  ' associated with the EditCommandColumn is clicked.

  ' Reset EditItemIndex to -1 which takes us out of edit mode
  dgrEmployees.EditItemIndex = -1
  Call BindDataSet()
End Sub

Sub GridUpdate(sender As Object, e As DataGridCommandEventArgs)
  ' This code is executed when the Update button 
  ' associated with the EditCommandColumn is clicked.

  Dim drFound As DataRow
 
  ' Find row in DataSet
  drFound = ds.Tables("Employees").Rows.Find(e.Item.Cells(2).Text)
  If Not drFound Is Nothing Then
    ' Grab controls from DataGrid
    Dim ctlFirstName As TextBox = e.Item.Cells(3).Controls(0)
    Dim ctlLastName As TextBox = e.Item.Cells(4).Controls(0)
    Dim ctlPhone As TextBox = e.Item.Cells(5).Controls(0)

    ' Set DataRow values to DataGrid control values
    drFound("FirstName") = ctlFirstName.Text
    drFound("LastName") = ctlLastName.Text
    drFound("HomePhone") = ctlPhone.Text
  Else
    lblMsg.Text = "Error: Row not found"
  End if 

  ' Reset EditItemIndex to -1 which takes us out of edit mode
  dgrEmployees.EditItemIndex = -1
  Session("ds") = ds
  Call BindDataSet()

  ' Need to fix up buttons.
  Call EnableDbButtons(ds.HasChanges())
End Sub

Sub GridCommand(sender As Object, e As DataGridCommandEventArgs)
  ' This code is executed when a Command button is clicked.
  ' The only Command button defined is for deleting rows.

  If e.CommandName = "Delete" Then
    Dim drFound As DataRow
 
    ' Find row in DataSet
    drFound = ds.Tables("Employees").Rows.Find(e.Item.Cells(2).Text)
    If Not drFound Is Nothing Then
      ' Grab controls from DataGrid
      drFound.Delete
    Else
      lblMsg.Text = "Error: Row not found"
    End if 

  ' Reset EditItemIndex to -1 which takes us out of edit mode
    dgrEmployees.EditItemIndex = -1
    Session("ds") = ds
    Call BindDataSet()

    ' Need to fix up buttons.
    Call EnableDbButtons(ds.HasChanges())
  Else
    ' Shouldn't happen
  End If
End Sub

Sub DbCommit(Src As Object, E As EventArgs)
  ' This routine is called when the 'Commit Changes'
  ' button is clicked. It sends all pending changes
  ' to the database.

  Dim intRows As Integer
  Dim strCnx As String = "server=localhost;uid=sa;pwd=;database=northwind;"
  Dim strSQL As String = "SELECT * FROM Employees"

  ' Create connection to SQL Server Northwind database
  Dim cnx As SqlConnection = New SqlConnection(strCnx)
  ' Create & execute SqlDataAdapter query to return records
  Dim sda As SqlDataAdapter = New SqlDataAdapter(strSQL, cnx)

  ' Create SqlCommandBuilder to handle Update statement
  Dim scb As SqlCommandBuilder = New SqlCommandBuilder(sda)
  sda.UpdateCommand = scb.GetUpdateCommand()
  sda.DeleteCommand = scb.GetDeleteCommand()

  ' Call Update method on Employees DataTable
  intRows = sda.Update(ds, "Employees")
  ' Reset state of edited rows
  ds.AcceptChanges()

  Call BindDataSet()
  cnx.Close()
  lblMsg.Text = intRows &  " database rows updated."

  ' Need to fix up buttons.
  Call EnableDbButtons(ds.HasChanges())
End Sub

Sub DbAbandon(Src As Object, E As EventArgs)
  ' This routine is called when the 'Abandon Changes'
  ' button is clicked. It forces a rebuild of the
  ' DataSet from the database.

  ' Rebuild DataSet from database
  Call BuildDataSet()
  Call BindDataSet()
  lblMsg.Text = "All changes abandoned."

  ' Need to fix up buttons.
  Call EnableDbButtons(ds.HasChanges())
End Sub
</script>
</head>
<body>
<form runat="server">
  <asp:Label id="lblOut" runat="server"
   Text="<h2>Northwind Employees</h2>" />

  <asp:DataGrid id="dgrEmployees" runat="server"
    BorderColor="black"
    BorderWidth="1"
    GridLines="Both"
    CellPadding="3"
    CellSpacing="0"
    Font-Name="Verdana"
    Font-Size="8pt"
    HeaderStyle-BackColor="#99ccff"
    AlternatingItemStyle-BackColor="lightgray"
    AutoGenerateColumns="False"
    OnEditCommand="GridEdit"
    OnCancelCommand="GridCancel"
    OnUpdateCommand="GridUpdate"
    OnItemCommand="GridCommand"
    >
    <Columns>
      <asp:EditCommandColumn
          EditText="Edit"
          UpdateText="Save"
          CancelText="Cancel"
          ItemStyle-Wrap="false"
          HeaderText="Edit"
          HeaderStyle-Wrap="false" />
       <asp:ButtonColumn 
          HeaderText="Delete" 
          Text="Delete" 
          CommandName="Delete" />
       <asp:BoundColumn HeaderText="Employee Id" DataField="EmployeeId"
        ReadOnly=True/>
       <asp:BoundColumn HeaderText="First Name" DataField="FirstName"/>
       <asp:BoundColumn HeaderText="Last Name" DataField="LastName"/>
       <asp:BoundColumn HeaderText="Phone" DataField="HomePhone"/>
    </Columns>
   </asp:DataGrid>
   <br />
   <asp:Button id="cmdDbCommit" runat="server"
    Text="Commit Changes" OnClick="DbCommit"/>
   <asp:Button id="cmdDbAbandon" runat="server"
    Text="Abandon Changes" OnClick="DbAbandon"/>
   <br /><br />
   <asp:Label  id="lblMsg" runat="server" 
    Style="Color:red"/>
</form>
</body>
</html>